==> system-keyboard-qt_24.04.01mx23.tar.xz: system-keyboard-qt/translations/system-keyboard-qt_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>FilterableComboBox</name>
    <message>
        <location filename="../filterablecombobox.cpp" line="12"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectLayoutDialog</name>
    <message>
        <location filename="../selectlayoutdialog.ui" line="14"/>
        <source>Select Keyboard Layout and Variant</source>
        <translation>Izberite razpored in različico tipkovnice</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.ui" line="29"/>
        <source>Layout</source>
        <translation>Razporeditev</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.ui" line="47"/>
        <source>Variants</source>
        <translation>Izvedbe</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.cpp" line="57"/>
        <source>No Variant</source>
        <translation>Brez izvedbe</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../window.ui" line="14"/>
        <location filename="../window.cpp" line="114"/>
        <location filename="../window.cpp" line="118"/>
        <source>System Keyboard</source>
        <translation>Sistemska tipkovnica</translation>
    </message>
    <message>
        <location filename="../window.ui" line="28"/>
        <source>Layouts</source>
        <translation>Razporeditve</translation>
    </message>
    <message>
        <location filename="../window.ui" line="34"/>
        <source>Keyboard Model</source>
        <translation>Model tipkovnice</translation>
    </message>
    <message>
        <source>search</source>
        <translation type="vanished">iskanje</translation>
    </message>
    <message>
        <location filename="../window.ui" line="46"/>
        <source>Keyboard Layouts</source>
        <translation>Razpored tipkovnice</translation>
    </message>
    <message>
        <location filename="../window.ui" line="136"/>
        <source>Hotkeys</source>
        <translation>Hitre tipke</translation>
    </message>
    <message>
        <location filename="../window.ui" line="159"/>
        <source>Advanced</source>
        <translation>Napredno</translation>
    </message>
    <message>
        <location filename="../window.ui" line="187"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="187"/>
        <location filename="../window.cpp" line="212"/>
        <location filename="../window.cpp" line="238"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="187"/>
        <location filename="../window.cpp" line="212"/>
        <location filename="../window.cpp" line="238"/>
        <source>Failed to open file: </source>
        <translation>Neuspešno odpiranje datoteke:</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="238"/>
        <source>Most settings will not be loaded</source>
        <translation>Večina nastavitev ne bo naloženih</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="vanished">Onemogočeno</translation>
    </message>
</context>
</TS>

==> system-keyboard-qt_25.04.02mx23.tar.xz: system-keyboard-qt/translations/system-keyboard-qt_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>FilterableComboBox</name>
    <message>
        <location filename="../filterablecombobox.cpp" line="12"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectLayoutDialog</name>
    <message>
        <location filename="../selectlayoutdialog.ui" line="14"/>
        <source>Select Keyboard Layout and Variant</source>
        <translation>Izberite razpored in različico tipkovnice</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.ui" line="29"/>
        <source>Layout</source>
        <translation>Razporeditev</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.ui" line="47"/>
        <source>Variants</source>
        <translation>Izvedbe</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.cpp" line="57"/>
        <source>No Variant</source>
        <translation>Brez izvedbe</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../window.ui" line="14"/>
        <location filename="../window.cpp" line="114"/>
        <location filename="../window.cpp" line="118"/>
        <source>System Keyboard</source>
        <translation>Sistemska tipkovnica</translation>
    </message>
    <message>
        <location filename="../window.ui" line="28"/>
        <source>Layouts</source>
        <translation>Razporeditve</translation>
    </message>
    <message>
        <location filename="../window.ui" line="34"/>
        <source>Keyboard Model</source>
        <translation>Model tipkovnice</translation>
    </message>
    <message>
        <source>search</source>
        <translation type="vanished">iskanje</translation>
    </message>
    <message>
        <location filename="../window.ui" line="46"/>
        <source>Keyboard Layouts</source>
        <translation>Razporeditve tipkovnic</translation>
    </message>
    <message>
        <location filename="../window.ui" line="136"/>
        <source>Hotkeys</source>
        <translation>Hitre tipke</translation>
    </message>
    <message>
        <location filename="../window.ui" line="159"/>
        <source>Advanced</source>
        <translation>Napredno</translation>
    </message>
    <message>
        <location filename="../window.ui" line="187"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="189"/>
        <location filename="../window.cpp" line="214"/>
        <location filename="../window.cpp" line="240"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="189"/>
        <location filename="../window.cpp" line="214"/>
        <location filename="../window.cpp" line="240"/>
        <source>Failed to open file: </source>
        <translation>Neuspešno odpiranje datoteke:</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="240"/>
        <source>Most settings will not be loaded</source>
        <translation>Večina nastavitev ne bo naloženih</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="vanished">Onemogočeno</translation>
    </message>
</context>
</TS>
